searchNodes=[{"doc":"The Concise Binary Object Representation (CBOR) is a data format whose design goals include the possibility of extremely small code size, fairly small message size, and extensibility without the need for version negotiation. These design goals make it different from earlier binary serializations such as ASN.1 and MessagePack. The objectives of CBOR, roughly in decreasing order of importance are: The representation must be able to unambiguously encode most common data formats used in Internet standards. It must represent a reasonable set of basic data types and structures using binary encoding. &quot;Reasonable&quot; here is largely influenced by the capabilities of JSON, with the major addition of binary byte strings. The structures supported are limited to arrays and trees; loops and lattice-style graphs are not supported. There is no requirement that all data formats be uniquely encoded; that is, it is acceptable that the number &quot;7&quot; might be encoded in multiple different ways. The code for an encoder or decoder must be able to be compact in order to support systems with very limited memory, processor power, and instruction sets. An encoder and a decoder need to be implementable in a very small amount of code (for example, in class 1 constrained nodes as defined in [CNN-TERMS]). The format should use contemporary machine representations of data (for example, not requiring binary-to-decimal conversion). Data must be able to be decoded without a schema description. Similar to JSON, encoded data should be self-describing so that a generic decoder can be written. The serialization must be reasonably compact, but data compactness is secondary to code compactness for the encoder and decoder. &quot;Reasonable&quot; here is bounded by JSON as an upper bound in size, and by implementation complexity maintaining a lower bound. Using either general compression schemes or extensive bit-fiddling violates the complexity goals. The format must be applicable to both constrained nodes and high- volume applications. This means it must be reasonably frugal in CPU usage for both encoding and decoding. This is relevant both for constrained nodes and for potential usage in applications with a very high volume of data. The format must support all JSON data types for conversion to and from JSON. It must support a reasonable level of conversion as long as the data represented is within the capabilities of JSON. It must be possible to define a unidirectional mapping towards JSON for all types of data. The format must be extensible, and the extended data must be decodable by earlier decoders. The format is designed for decades of use. The format must support a form of extensibility that allows fallback so that a decoder that does not understand an extension can still decode the message. The format must be able to be extended in the future by later IETF standards.","ref":"CBOR.html","title":"CBOR","type":"module"},{"doc":"Converts a CBOR encoded binary into native elixir data structures Examples iex&gt; CBOR . decode ( &lt;&lt; 130 , 101 , 72 , 101 , 108 , 108 , 111 , 102 , 87 , 111 , 114 , 108 , 100 , 33 &gt;&gt; ) { :ok , [ &quot;Hello&quot; , &quot;World!&quot; ] , &quot;&quot; } iex&gt; CBOR . decode ( &lt;&lt; 130 , 1 , 130 , 2 , 3 &gt;&gt; ) { :ok , [ 1 , [ 2 , 3 ] ] , &quot;&quot; } iex&gt; CBOR . decode ( &lt;&lt; 162 , 97 , 97 , 1 , 97 , 98 , 130 , 2 , 3 &gt;&gt; ) { :ok , %{ &quot;a&quot; =&gt; 1 , &quot;b&quot; =&gt; [ 2 , 3 ] } , &quot;&quot; }","ref":"CBOR.html#decode/1","title":"CBOR.decode/1","type":"function"},{"doc":"Returns a binary encoding of the data in a format that can be interpreted by other CBOR libraries. Examples iex&gt; CBOR . encode ( [ &quot;Hello&quot; , &quot;World!&quot; ] ) &lt;&lt; 130 , 101 , 72 , 101 , 108 , 108 , 111 , 102 , 87 , 111 , 114 , 108 , 100 , 33 &gt;&gt; iex&gt; CBOR . encode ( [ 1 , [ 2 , 3 ] ] ) &lt;&lt; 130 , 1 , 130 , 2 , 3 &gt;&gt; iex&gt; CBOR . encode ( %{ &quot;a&quot; =&gt; 1 , &quot;b&quot; =&gt; [ 2 , 3 ] } ) &lt;&lt; 162 , 97 , 97 , 1 , 97 , 98 , 130 , 2 , 3 &gt;&gt;","ref":"CBOR.html#encode/1","title":"CBOR.encode/1","type":"function"},{"doc":"","ref":"CBOR.Decoder.html","title":"CBOR.Decoder","type":"module"},{"doc":"","ref":"CBOR.Decoder.html#decode/1","title":"CBOR.Decoder.decode/1","type":"function"},{"doc":"","ref":"CBOR.Decoder.html#decode/2","title":"CBOR.Decoder.decode/2","type":"function"},{"doc":"","ref":"CBOR.Decoder.html#decode_non_finite/2","title":"CBOR.Decoder.decode_non_finite/2","type":"function"},{"doc":"","ref":"CBOR.Encoder.html","title":"CBOR.Encoder","type":"protocol"},{"doc":"Converts an Elixir data type to its representation in CBOR.","ref":"CBOR.Encoder.html#encode_into/2","title":"CBOR.Encoder.encode_into/2","type":"function"},{"doc":"","ref":"CBOR.Encoder.html#t:t/0","title":"CBOR.Encoder.t/0","type":"type"},{"doc":"","ref":"CBOR.Tag.html","title":"CBOR.Tag","type":"module"},{"doc":"","ref":"CBOR.Utils.html","title":"CBOR.Utils","type":"module"},{"doc":"","ref":"CBOR.Utils.html#encode_head/3","title":"CBOR.Utils.encode_head/3","type":"function"},{"doc":"","ref":"CBOR.Utils.html#encode_string/3","title":"CBOR.Utils.encode_string/3","type":"function"},{"doc":"MIT License Copyright (c) 2019 Thomas Cioppettini Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"CBOR Implementation of RFC 7049 CBOR (Concise Binary Object Representation) for Elixir. This is a fork of excbor which modernizes the codebase, and makes decisions on handling data types that the original library had punted on.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"This library is a fork of the no longer maintained excbor project. For those migrating from previous versions of this library there are breaking changes that you should be aware of. The module Cbor has been renamed to CBOR . CBOR.decode will return a three item tuple of the form {:ok, decoded, rest} , instead of returning the decoded object. In the wild there are APIs that concat CBOR objects together. The rest variable includes any leftover information from the decoding operation in case you need to decode multiple objects. Atoms will be encoded/decoded as strings, except for the special case of :__undefined__ which has no direct translation to elixir but has semantic meaning in CBOR. Elixir/Erlang does not have a concept of infinity, negative infinity or NaN. In order to encode or decode these values we will return a struct of the form %CBOR.Tag{tag: :float, value: (:inf|:&quot;-inf&quot;|:nan)} If you want to encode a raw binary value, you can use the CBOR.Tag struct with a tag of :bytes and the binary as the :value field.","ref":"readme.html#migrating-from-the-previous-version","title":"Overview - Migrating from the previous version","type":"extras"},{"doc":"def deps do [ { :cbor , &quot;~&gt; 1.0.0&quot; } ] end","ref":"readme.html#installation","title":"Overview - Installation","type":"extras"},{"doc":"This library follows the standard API for CBOR libraries by exposing two methods on the CBOR module CBOR.encode/1 and CBOR.decode/1 . Encoding iex(1)&gt; CBOR . encode ( [ 1 , [ 2 , 3 ] ] ) &lt;&lt; 130 , 1 , 130 , 2 , 3 &gt;&gt; Decoding iex(2)&gt; CBOR . decode ( &lt;&lt; 130 , 1 , 130 , 2 , 3 &gt;&gt; ) { :ok , [ 1 , [ 2 , 3 ] ] , &quot;&quot; }","ref":"readme.html#usage","title":"Overview - Usage","type":"extras"},{"doc":"Given that Elixir has more available data types than are supported in CBOR, decisions were made so that encoding complex data structures succeed without throwing errors. My thoughts are collected below so you can understand why encoding and decoding of a value does not necessarily return exactly the same value. Atoms The only atoms that will be directly encoded are true , false nil and __undefined__ . Every other atom will be converted to a string before being encoded. We surround undefined with double underscores so that you only encode an undefined value when you clearly intend to do so. Keyword List, MapSet, Range, Tuple All of the above data structures are converted to Lists before being encoded. This ensures that there is no data lost when encoding and decoding. NaiveDateTime NaiveDateTime will be treated as if they are UTC. Special Values Elixir and erlang have no concept of infinity, negative infinity and NaN. If you want to encode those values, we have a special struct CBOR.Tag which you can use to represent those values. % CBOR.Tag { tag : :float , value : :inf } % CBOR.Tag { tag : :float , value : :&quot;-inf&quot; } % CBOR.Tag { tag : :float , value : :nan } CBOR.Tag is also useful if you want to extend CBOR for internal applications","ref":"readme.html#design-notes","title":"Overview - Design Notes","type":"extras"},{"doc":"If you want to encode something that is not supported out of the box you can implement the CBOR.Encoder protocol for the module. You only have to implement a single CBOR.Encoder.encode_into/2 function. An example for encoding a Money struct is given below. defimpl CBOR.Encoder , for : Money do def encode_into ( money , acc ) do money |&gt; Money . to_string ( ) |&gt; CBOR.Encoder . encode_into ( acc ) end end Documentation Documentation can be generated with ExDoc and published on HexDocs . Once published, the docs can be found at https://hexdocs.pm/cbor .","ref":"readme.html#custom-encoding","title":"Overview - Custom Encoding","type":"extras"},{"doc":"Copyright (c) 2019 Thomas Cioppettini This work is free. You can redistribute it and/or modify it under the terms of the MIT License. See the LICENSE.md file for more details.","ref":"readme.html#copyright-and-license","title":"Overview - Copyright and License","type":"extras"}]